/* collection.c generated by valac 0.37.1.4-3591e, the Vala compiler
 * generated from collection.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <libcommon.h>
#include <gtk/gtk.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;
enum  {
	BOXES_COLLECTION_ITEM_DUMMY_PROPERTY,
	BOXES_COLLECTION_ITEM_NAME,
	BOXES_COLLECTION_ITEM_PREVIOUS_UI_STATE,
	BOXES_COLLECTION_ITEM_UI_STATE,
	BOXES_COLLECTION_ITEM_LAST_PROPERTY
};
static GParamSpec* boxes_collection_item_properties[BOXES_COLLECTION_ITEM_LAST_PROPERTY];
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;
enum  {
	BOXES_COLLECTION_DUMMY_PROPERTY,
	BOXES_COLLECTION_LAST_PROPERTY
};
static GParamSpec* boxes_collection_properties[BOXES_COLLECTION_LAST_PROPERTY];
#define _g_ptr_array_unref0(var) ((var == NULL) ? NULL : (var = (g_ptr_array_unref (var), NULL)))

#define BOXES_TYPE_ICOLLECTION_VIEW (boxes_icollection_view_get_type ())
#define BOXES_ICOLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ICOLLECTION_VIEW, BoxesICollectionView))
#define BOXES_IS_ICOLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ICOLLECTION_VIEW))
#define BOXES_ICOLLECTION_VIEW_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_ICOLLECTION_VIEW, BoxesICollectionViewIface))

typedef struct _BoxesICollectionView BoxesICollectionView;
typedef struct _BoxesICollectionViewIface BoxesICollectionViewIface;

#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
enum  {
	BOXES_COLLECTION_ITEM_ADDED_SIGNAL,
	BOXES_COLLECTION_ITEM_REMOVED_SIGNAL,
	BOXES_COLLECTION_LAST_SIGNAL
};
static guint boxes_collection_signals[BOXES_COLLECTION_LAST_SIGNAL] = {0};
typedef struct _BoxesCollectionFilterPrivate BoxesCollectionFilterPrivate;
enum  {
	BOXES_COLLECTION_FILTER_DUMMY_PROPERTY,
	BOXES_COLLECTION_FILTER_TEXT,
	BOXES_COLLECTION_FILTER_LAST_PROPERTY
};
static GParamSpec* boxes_collection_filter_properties[BOXES_COLLECTION_FILTER_LAST_PROPERTY];
enum  {
	BOXES_COLLECTION_FILTER_FILTER_FUNC_CHANGED_SIGNAL,
	BOXES_COLLECTION_FILTER_LAST_SIGNAL
};
static guint boxes_collection_filter_signals[BOXES_COLLECTION_FILTER_LAST_SIGNAL] = {0};

#define BOXES_TYPE_CATEGORY (boxes_category_get_type ())
#define BOXES_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CATEGORY, BoxesCategory))
#define BOXES_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CATEGORY, BoxesCategoryClass))
#define BOXES_IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CATEGORY))
#define BOXES_IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CATEGORY))
#define BOXES_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CATEGORY, BoxesCategoryClass))

typedef struct _BoxesCategory BoxesCategory;
typedef struct _BoxesCategoryClass BoxesCategoryClass;
typedef struct _BoxesCategoryPrivate BoxesCategoryPrivate;

#define BOXES_CATEGORY_TYPE_KIND (boxes_category_kind_get_type ())
enum  {
	BOXES_CATEGORY_DUMMY_PROPERTY,
	BOXES_CATEGORY_LAST_PROPERTY
};
static GParamSpec* boxes_category_properties[BOXES_CATEGORY_LAST_PROPERTY];

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

struct _BoxesCollectionItemPrivate {
	gchar* _name;
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

struct _BoxesICollectionViewIface {
	GTypeInterface parent_iface;
	void (*add_item) (BoxesICollectionView* self, BoxesCollectionItem* item);
	void (*remove_item) (BoxesICollectionView* self, BoxesCollectionItem* item);
	GList* (*get_selected_items) (BoxesICollectionView* self);
	void (*activate_first_item) (BoxesICollectionView* self);
	void (*select_by_criteria) (BoxesICollectionView* self, BoxesSelectionCriteria criteria);
	BoxesCollectionFilter* (*get_filter) (BoxesICollectionView* self);
	void (*set_filter) (BoxesICollectionView* self, BoxesCollectionFilter* value);
};

struct _BoxesCollectionFilter {
	GObject parent_instance;
	BoxesCollectionFilterPrivate * priv;
};

struct _BoxesCollectionFilterClass {
	GObjectClass parent_class;
};

typedef gboolean (*BoxesCollectionFilterFunc) (BoxesCollectionItem* item, void* user_data);
struct _BoxesCollectionFilterPrivate {
	gchar** terms;
	gint terms_length1;
	gint _terms_size_;
	gchar* _text;
	BoxesCollectionFilterFunc _filter_func;
	gpointer _filter_func_target;
};

typedef enum  {
	BOXES_CATEGORY_KIND_USER,
	BOXES_CATEGORY_KIND_NEW,
	BOXES_CATEGORY_KIND_FAVORITES,
	BOXES_CATEGORY_KIND_PRIVATE,
	BOXES_CATEGORY_KIND_SHARED
} BoxesCategoryKind;

struct _BoxesCategory {
	GObject parent_instance;
	BoxesCategoryPrivate * priv;
	gchar* name;
	BoxesCategoryKind kind;
};

struct _BoxesCategoryClass {
	GObjectClass parent_class;
};


static gpointer boxes_collection_item_parent_class = NULL;
static BoxesUIIface * boxes_collection_item_boxes_ui_parent_iface = NULL;
static gpointer boxes_collection_parent_class = NULL;
static gpointer boxes_collection_filter_parent_class = NULL;
static gpointer boxes_category_parent_class = NULL;

GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
#define BOXES_COLLECTION_ITEM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemPrivate))
gint boxes_collection_item_compare (BoxesCollectionItem* self, BoxesCollectionItem* other);
static gint boxes_collection_item_real_compare (BoxesCollectionItem* self, BoxesCollectionItem* other);
GType boxes_machine_get_type (void) G_GNUC_CONST;
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
BoxesCollectionItem* boxes_collection_item_construct (GType object_type);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
static void boxes_collection_item_finalize (GObject * obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void _vala_boxes_collection_item_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_collection_item_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType boxes_collection_get_type (void) G_GNUC_CONST;
BoxesCollection* boxes_collection_new (void);
BoxesCollection* boxes_collection_construct (GType object_type);
void boxes_collection_add_item (BoxesCollection* self, BoxesCollectionItem* item);
void boxes_collection_remove_item (BoxesCollection* self, BoxesCollectionItem* item);
GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_icollection_view_get_type (void) G_GNUC_CONST;
void boxes_collection_populate (BoxesCollection* self, BoxesICollectionView* view);
void boxes_icollection_view_add_item (BoxesICollectionView* self, BoxesCollectionItem* item);
static GObject * boxes_collection_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _g_object_unref0_ (gpointer var);
static void boxes_collection_finalize (GObject * obj);
#define BOXES_COLLECTION_FILTER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterPrivate))
gboolean boxes_collection_filter_filter (BoxesCollectionFilter* self, BoxesCollectionItem* item);
BoxesCollectionFilterFunc boxes_collection_filter_get_filter_func (BoxesCollectionFilter* self, gpointer* result_target);
BoxesCollectionFilter* boxes_collection_filter_new (void);
BoxesCollectionFilter* boxes_collection_filter_construct (GType object_type);
const gchar* boxes_collection_filter_get_text (BoxesCollectionFilter* self);
void boxes_collection_filter_set_text (BoxesCollectionFilter* self, const gchar* value);
void boxes_collection_filter_set_filter_func (BoxesCollectionFilter* self, BoxesCollectionFilterFunc value, gpointer value_target);
static void boxes_collection_filter_finalize (GObject * obj);
static void _vala_boxes_collection_filter_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_collection_filter_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType boxes_category_get_type (void) G_GNUC_CONST;
GType boxes_category_kind_get_type (void) G_GNUC_CONST;
BoxesCategory* boxes_category_new (const gchar* name, BoxesCategoryKind kind);
BoxesCategory* boxes_category_construct (GType object_type, const gchar* name, BoxesCategoryKind kind);
static void boxes_category_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static gint boxes_collection_item_real_compare (BoxesCollectionItem* self, BoxesCollectionItem* other) {
	gint result = 0;
	BoxesCollectionItem* _tmp0_;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_;
	gboolean _tmp3_;
	const gchar* _tmp11_;
	gboolean _tmp12_;
	BoxesCollectionItem* _tmp13_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
#line 9 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_val_if_fail (other != NULL, 0);
#line 11 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = other;
#line 11 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_MACHINE)) {
#line 12 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		result = 1;
#line 12 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		return result;
#line 305 "collection.c"
	}
#line 16 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp2_ = self->priv->_name;
#line 16 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp3_ = boxes_is_set (_tmp2_);
#line 16 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	if (_tmp3_) {
#line 313 "collection.c"
		BoxesCollectionItem* _tmp4_;
		const gchar* _tmp5_;
		gboolean _tmp6_;
#line 16 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp4_ = other;
#line 16 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp5_ = _tmp4_->priv->_name;
#line 16 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp6_ = boxes_is_set (_tmp5_);
#line 16 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp1_ = _tmp6_;
#line 325 "collection.c"
	} else {
#line 16 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp1_ = FALSE;
#line 329 "collection.c"
	}
#line 16 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	if (_tmp1_) {
#line 333 "collection.c"
		const gchar* _tmp7_;
		BoxesCollectionItem* _tmp8_;
		const gchar* _tmp9_;
		gint _tmp10_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp7_ = self->priv->_name;
#line 17 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp8_ = other;
#line 17 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp9_ = _tmp8_->priv->_name;
#line 17 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp10_ = g_utf8_collate (_tmp7_, _tmp9_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		result = _tmp10_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		return result;
#line 350 "collection.c"
	}
#line 20 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp11_ = self->priv->_name;
#line 20 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp12_ = boxes_is_set (_tmp11_);
#line 20 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	if (_tmp12_) {
#line 21 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		result = -1;
#line 21 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		return result;
#line 362 "collection.c"
	}
#line 22 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp13_ = other;
#line 22 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp14_ = _tmp13_->priv->_name;
#line 22 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp15_ = boxes_is_set (_tmp14_);
#line 22 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	if (_tmp15_) {
#line 23 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		result = 1;
#line 23 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		return result;
#line 376 "collection.c"
	}
#line 25 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	result = 0;
#line 25 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return result;
#line 382 "collection.c"
}


gint boxes_collection_item_compare (BoxesCollectionItem* self, BoxesCollectionItem* other) {
#line 9 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 9 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return BOXES_COLLECTION_ITEM_GET_CLASS (self)->compare (self, other);
#line 391 "collection.c"
}


BoxesCollectionItem* boxes_collection_item_construct (GType object_type) {
	BoxesCollectionItem * self = NULL;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = (BoxesCollectionItem*) g_object_new (object_type, NULL);
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return self;
#line 401 "collection.c"
}


const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = self->priv->_name;
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	result = _tmp0_;
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return result;
#line 416 "collection.c"
}


void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_if_fail (self != NULL);
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	if (g_strcmp0 (value, boxes_collection_item_get_name (self)) != 0) {
#line 425 "collection.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp0_ = value;
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_g_free0 (self->priv->_name);
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		self->priv->_name = _tmp1_;
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_collection_item_properties[BOXES_COLLECTION_ITEM_NAME]);
#line 438 "collection.c"
	}
}


static BoxesUIState boxes_collection_item_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesCollectionItem* self;
	BoxesUIState _tmp0_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = (BoxesCollectionItem*) base;
#line 6 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 6 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	result = _tmp0_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return result;
#line 455 "collection.c"
}


static void boxes_collection_item_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesCollectionItem* self;
#line 6 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = (BoxesCollectionItem*) base;
#line 6 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	if (boxes_collection_item_real_get_previous_ui_state (base) != value) {
#line 465 "collection.c"
		BoxesUIState _tmp0_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp0_ = value;
#line 6 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		self->priv->_previous_ui_state = _tmp0_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_collection_item_properties[BOXES_COLLECTION_ITEM_PREVIOUS_UI_STATE]);
#line 473 "collection.c"
	}
}


static BoxesUIState boxes_collection_item_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesCollectionItem* self;
	BoxesUIState _tmp0_;
#line 7 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = (BoxesCollectionItem*) base;
#line 7 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = self->priv->_ui_state;
#line 7 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	result = _tmp0_;
#line 7 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return result;
#line 490 "collection.c"
}


static void boxes_collection_item_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesCollectionItem* self;
#line 7 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = (BoxesCollectionItem*) base;
#line 7 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	if (boxes_collection_item_real_get_ui_state (base) != value) {
#line 500 "collection.c"
		BoxesUIState _tmp0_;
#line 7 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp0_ = value;
#line 7 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		self->priv->_ui_state = _tmp0_;
#line 7 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_collection_item_properties[BOXES_COLLECTION_ITEM_UI_STATE]);
#line 508 "collection.c"
	}
}


static void boxes_collection_item_class_init (BoxesCollectionItemClass * klass) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	boxes_collection_item_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_type_class_add_private (klass, sizeof (BoxesCollectionItemPrivate));
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	((BoxesCollectionItemClass *) klass)->compare = (gint (*) (BoxesCollectionItem *, BoxesCollectionItem*)) boxes_collection_item_real_compare;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_collection_item_get_property;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_collection_item_set_property;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_collection_item_finalize;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_ITEM_NAME, boxes_collection_item_properties[BOXES_COLLECTION_ITEM_NAME] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_ITEM_PREVIOUS_UI_STATE, boxes_collection_item_properties[BOXES_COLLECTION_ITEM_PREVIOUS_UI_STATE] = g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_ITEM_UI_STATE, boxes_collection_item_properties[BOXES_COLLECTION_ITEM_UI_STATE] = g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 532 "collection.c"
}


static void boxes_collection_item_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	boxes_collection_item_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	iface->get_previous_ui_state = boxes_collection_item_real_get_previous_ui_state;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	iface->set_previous_ui_state = boxes_collection_item_real_set_previous_ui_state;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	iface->get_ui_state = boxes_collection_item_real_get_ui_state;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	iface->set_ui_state = boxes_collection_item_real_set_ui_state;
#line 547 "collection.c"
}


static void boxes_collection_item_instance_init (BoxesCollectionItem * self) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->priv = BOXES_COLLECTION_ITEM_GET_PRIVATE (self);
#line 554 "collection.c"
}


static void boxes_collection_item_finalize (GObject * obj) {
	BoxesCollectionItem * self;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem);
#line 4 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_g_free0 (self->priv->_name);
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (boxes_collection_item_parent_class)->finalize (obj);
#line 566 "collection.c"
}


GType boxes_collection_item_get_type (void) {
	static volatile gsize boxes_collection_item_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_item_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesCollectionItemClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_collection_item_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesCollectionItem), 0, (GInstanceInitFunc) boxes_collection_item_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_collection_item_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_collection_item_type_id;
		boxes_collection_item_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesCollectionItem", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (boxes_collection_item_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_collection_item_type_id__volatile, boxes_collection_item_type_id);
	}
	return boxes_collection_item_type_id__volatile;
}


static void _vala_boxes_collection_item_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesCollectionItem * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem);
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	switch (property_id) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		case BOXES_COLLECTION_ITEM_NAME:
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		g_value_set_string (value, boxes_collection_item_get_name (self));
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		case BOXES_COLLECTION_ITEM_PREVIOUS_UI_STATE:
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		case BOXES_COLLECTION_ITEM_UI_STATE:
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 607 "collection.c"
		default:
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 613 "collection.c"
	}
}


static void _vala_boxes_collection_item_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesCollectionItem * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem);
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	switch (property_id) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		case BOXES_COLLECTION_ITEM_NAME:
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		boxes_collection_item_set_name (self, g_value_get_string (value));
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		case BOXES_COLLECTION_ITEM_PREVIOUS_UI_STATE:
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		case BOXES_COLLECTION_ITEM_UI_STATE:
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 641 "collection.c"
		default:
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 647 "collection.c"
	}
}


BoxesCollection* boxes_collection_construct (GType object_type) {
	BoxesCollection * self = NULL;
#line 39 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = (BoxesCollection*) g_object_new (object_type, NULL);
#line 39 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return self;
#line 658 "collection.c"
}


BoxesCollection* boxes_collection_new (void) {
#line 39 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return boxes_collection_construct (BOXES_TYPE_COLLECTION);
#line 665 "collection.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 43 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return self ? g_object_ref (self) : NULL;
#line 672 "collection.c"
}


void boxes_collection_add_item (BoxesCollection* self, BoxesCollectionItem* item) {
	GPtrArray* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
	BoxesCollectionItem* _tmp3_;
#line 42 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_if_fail (self != NULL);
#line 42 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_if_fail (item != NULL);
#line 43 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = self->items;
#line 43 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp1_ = item;
#line 43 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 43 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_ptr_array_add (_tmp0_, _tmp2_);
#line 44 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp3_ = item;
#line 44 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_signal_emit (self, boxes_collection_signals[BOXES_COLLECTION_ITEM_ADDED_SIGNAL], 0, _tmp3_);
#line 697 "collection.c"
}


void boxes_collection_remove_item (BoxesCollection* self, BoxesCollectionItem* item) {
	GPtrArray* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_if_fail (item != NULL);
#line 48 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = self->items;
#line 48 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp1_ = item;
#line 48 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_ptr_array_remove (_tmp0_, _tmp1_);
#line 49 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp2_ = item;
#line 49 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_signal_emit (self, boxes_collection_signals[BOXES_COLLECTION_ITEM_REMOVED_SIGNAL], 0, _tmp2_);
#line 719 "collection.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_;
#line 4981 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4981 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4981 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4981 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 734 "collection.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_;
#line 4982 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4982 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4982 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 746 "collection.c"
}


void boxes_collection_populate (BoxesCollection* self, BoxesICollectionView* view) {
#line 52 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_if_fail (self != NULL);
#line 52 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_if_fail (view != NULL);
#line 755 "collection.c"
	{
		guint i = 0U;
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		i = (guint) 0;
#line 760 "collection.c"
		{
			gboolean _tmp0_ = FALSE;
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
			_tmp0_ = TRUE;
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
			while (TRUE) {
#line 767 "collection.c"
				guint _tmp2_;
				GPtrArray* _tmp3_;
				gint _tmp4_;
				gint _tmp5_;
				BoxesICollectionView* _tmp6_;
				GPtrArray* _tmp7_;
				guint _tmp8_;
				gconstpointer _tmp9_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				if (!_tmp0_) {
#line 778 "collection.c"
					guint _tmp1_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
					_tmp1_ = i;
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
					i = _tmp1_ + 1;
#line 784 "collection.c"
				}
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp0_ = FALSE;
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp2_ = i;
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp3_ = self->items;
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp4_ = g_ptr_array_get_length (_tmp3_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp5_ = _tmp4_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				if (!(_tmp2_ < ((guint) _tmp5_))) {
#line 53 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
					break;
#line 800 "collection.c"
				}
#line 54 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp6_ = view;
#line 54 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp7_ = self->items;
#line 54 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp8_ = i;
#line 54 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp9_ = g_ptr_array_index (_tmp7_, _tmp8_);
#line 54 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				boxes_icollection_view_add_item (_tmp6_, (BoxesCollectionItem*) _tmp9_);
#line 812 "collection.c"
			}
		}
	}
}


static void _g_object_unref0_ (gpointer var) {
#line 36 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 822 "collection.c"
}


static GObject * boxes_collection_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesCollection * self;
	GPtrArray* _tmp0_;
#line 35 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	parent_class = G_OBJECT_CLASS (boxes_collection_parent_class);
#line 35 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 35 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION, BoxesCollection);
#line 36 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = g_ptr_array_new_full ((guint) 0, _g_object_unref0_);
#line 36 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_g_ptr_array_unref0 (self->items);
#line 36 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->items = _tmp0_;
#line 35 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return obj;
#line 845 "collection.c"
}


static void boxes_collection_class_init (BoxesCollectionClass * klass) {
#line 29 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	boxes_collection_parent_class = g_type_class_peek_parent (klass);
#line 29 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_collection_constructor;
#line 29 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_collection_finalize;
#line 29 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	boxes_collection_signals[BOXES_COLLECTION_ITEM_ADDED_SIGNAL] = g_signal_new ("item-added", BOXES_TYPE_COLLECTION, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, BOXES_TYPE_COLLECTION_ITEM);
#line 29 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	boxes_collection_signals[BOXES_COLLECTION_ITEM_REMOVED_SIGNAL] = g_signal_new ("item-removed", BOXES_TYPE_COLLECTION, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, BOXES_TYPE_COLLECTION_ITEM);
#line 860 "collection.c"
}


static void boxes_collection_instance_init (BoxesCollection * self) {
}


static void boxes_collection_finalize (GObject * obj) {
	BoxesCollection * self;
#line 29 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION, BoxesCollection);
#line 33 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_g_ptr_array_unref0 (self->items);
#line 29 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (boxes_collection_parent_class)->finalize (obj);
#line 876 "collection.c"
}


GType boxes_collection_get_type (void) {
	static volatile gsize boxes_collection_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesCollection), 0, (GInstanceInitFunc) boxes_collection_instance_init, NULL };
		GType boxes_collection_type_id;
		boxes_collection_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesCollection", &g_define_type_info, 0);
		g_once_init_leave (&boxes_collection_type_id__volatile, boxes_collection_type_id);
	}
	return boxes_collection_type_id__volatile;
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1411 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1411 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1412 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1412 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1412 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1412 "/home/fborges/jhbuild/install/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 908 "collection.c"
}


gboolean boxes_collection_filter_filter (BoxesCollectionFilter* self, BoxesCollectionItem* item) {
	gboolean result = FALSE;
	gchar* name = NULL;
	BoxesCollectionItem* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
	BoxesCollectionFilterFunc _tmp9_;
	void* _tmp9__target;
	BoxesCollectionFilterFunc _tmp10_;
	void* _tmp10__target;
#line 85 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 85 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 86 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = item;
#line 86 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp1_ = boxes_collection_item_get_name (_tmp0_);
#line 86 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp2_ = _tmp1_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp3_ = boxes_canonicalize_for_search (_tmp2_);
#line 86 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	name = _tmp3_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp4_ = self->priv->terms;
#line 87 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp4__length1 = self->priv->terms_length1;
#line 943 "collection.c"
	{
		gchar** term_collection = NULL;
		gint term_collection_length1 = 0;
		gint _term_collection_size_ = 0;
		gint term_it = 0;
#line 87 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		term_collection = _tmp4_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		term_collection_length1 = _tmp4__length1;
#line 87 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		for (term_it = 0; term_it < _tmp4__length1; term_it = term_it + 1) {
#line 955 "collection.c"
			gchar* _tmp5_;
			gchar* term = NULL;
#line 87 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
			_tmp5_ = g_strdup (term_collection[term_it]);
#line 87 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
			term = _tmp5_;
#line 962 "collection.c"
			{
				const gchar* _tmp6_;
				const gchar* _tmp7_;
				gboolean _tmp8_;
#line 88 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp6_ = name;
#line 88 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp7_ = term;
#line 88 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp8_ = string_contains (_tmp6_, _tmp7_);
#line 88 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				if (!_tmp8_) {
#line 89 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
					result = FALSE;
#line 89 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
					_g_free0 (term);
#line 89 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
					_g_free0 (name);
#line 89 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
					return result;
#line 983 "collection.c"
				}
#line 87 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_g_free0 (term);
#line 987 "collection.c"
			}
		}
	}
#line 92 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp9_ = boxes_collection_filter_get_filter_func (self, &_tmp9__target);
#line 92 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp10_ = _tmp9_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp10__target = _tmp9__target;
#line 92 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	if (_tmp10_ != NULL) {
#line 999 "collection.c"
		BoxesCollectionFilterFunc _tmp11_;
		void* _tmp11__target;
		BoxesCollectionFilterFunc _tmp12_;
		void* _tmp12__target;
		BoxesCollectionItem* _tmp13_;
		gboolean _tmp14_;
#line 93 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp11_ = boxes_collection_filter_get_filter_func (self, &_tmp11__target);
#line 93 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp12_ = _tmp11_;
#line 93 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp12__target = _tmp11__target;
#line 93 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp13_ = item;
#line 93 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_tmp14_ = _tmp12_ (_tmp13_, _tmp12__target);
#line 93 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		result = _tmp14_;
#line 93 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		_g_free0 (name);
#line 93 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		return result;
#line 1022 "collection.c"
	}
#line 95 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	result = TRUE;
#line 95 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_g_free0 (name);
#line 95 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return result;
#line 1030 "collection.c"
}


BoxesCollectionFilter* boxes_collection_filter_construct (GType object_type) {
	BoxesCollectionFilter * self = NULL;
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = (BoxesCollectionFilter*) g_object_new (object_type, NULL);
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return self;
#line 1040 "collection.c"
}


BoxesCollectionFilter* boxes_collection_filter_new (void) {
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return boxes_collection_filter_construct (BOXES_TYPE_COLLECTION_FILTER);
#line 1047 "collection.c"
}


const gchar* boxes_collection_filter_get_text (BoxesCollectionFilter* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 66 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 66 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = self->priv->_text;
#line 66 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	result = _tmp0_;
#line 66 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return result;
#line 1062 "collection.c"
}


void boxes_collection_filter_set_text (BoxesCollectionFilter* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar** _tmp3_;
	gchar** _tmp4_;
#line 67 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_if_fail (self != NULL);
#line 68 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = value;
#line 68 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 68 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_g_free0 (self->priv->_text);
#line 68 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->priv->_text = _tmp1_;
#line 69 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp2_ = value;
#line 69 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp4_ = _tmp3_ = g_strsplit (_tmp2_, " ", 0);
#line 69 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->priv->terms = (_vala_array_free (self->priv->terms, self->priv->terms_length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->priv->terms = _tmp4_;
#line 69 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->priv->terms_length1 = _vala_array_length (_tmp3_);
#line 69 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->priv->_terms_size_ = self->priv->terms_length1;
#line 1094 "collection.c"
	{
		gint i = 0;
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		i = 0;
#line 1099 "collection.c"
		{
			gboolean _tmp5_ = FALSE;
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
			_tmp5_ = TRUE;
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
			while (TRUE) {
#line 1106 "collection.c"
				gint _tmp7_;
				gchar** _tmp8_;
				gint _tmp8__length1;
				gchar** _tmp9_;
				gint _tmp9__length1;
				gint _tmp10_;
				gchar** _tmp11_;
				gint _tmp11__length1;
				gint _tmp12_;
				const gchar* _tmp13_;
				gchar* _tmp14_;
				gchar* _tmp15_;
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				if (!_tmp5_) {
#line 1121 "collection.c"
					gint _tmp6_;
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
					_tmp6_ = i;
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
					i = _tmp6_ + 1;
#line 1127 "collection.c"
				}
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp5_ = FALSE;
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp7_ = i;
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp8_ = self->priv->terms;
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp8__length1 = self->priv->terms_length1;
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				if (!(_tmp7_ < _tmp8__length1)) {
#line 70 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
					break;
#line 1141 "collection.c"
				}
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp9_ = self->priv->terms;
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp9__length1 = self->priv->terms_length1;
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp10_ = i;
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp11_ = self->priv->terms;
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp11__length1 = self->priv->terms_length1;
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp12_ = i;
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp13_ = _tmp11_[_tmp12_];
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp14_ = boxes_canonicalize_for_search (_tmp13_);
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_g_free0 (_tmp9_[_tmp10_]);
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp9_[_tmp10_] = _tmp14_;
#line 71 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
				_tmp15_ = _tmp9_[_tmp10_];
#line 1165 "collection.c"
			}
		}
	}
#line 67 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_collection_filter_properties[BOXES_COLLECTION_FILTER_TEXT]);
#line 1171 "collection.c"
}


BoxesCollectionFilterFunc boxes_collection_filter_get_filter_func (BoxesCollectionFilter* self, gpointer* result_target) {
	BoxesCollectionFilterFunc result;
	BoxesCollectionFilterFunc _tmp0_;
	void* _tmp0__target;
	BoxesCollectionFilterFunc _tmp1_;
	void* _tmp1__target;
#line 77 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 77 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = self->priv->_filter_func;
#line 77 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0__target = self->priv->_filter_func_target;
#line 77 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp1_ = _tmp0_;
#line 77 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp1__target = _tmp0__target;
#line 77 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	*result_target = _tmp1__target;
#line 77 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	result = _tmp1_;
#line 77 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return result;
#line 1197 "collection.c"
}


void boxes_collection_filter_set_filter_func (BoxesCollectionFilter* self, BoxesCollectionFilterFunc value, gpointer value_target) {
	BoxesCollectionFilterFunc _tmp0_;
	void* _tmp0__target;
#line 78 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_if_fail (self != NULL);
#line 79 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = value;
#line 79 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0__target = value_target;
#line 79 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->priv->_filter_func = _tmp0_;
#line 79 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->priv->_filter_func_target = _tmp0__target;
#line 80 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_signal_emit (self, boxes_collection_filter_signals[BOXES_COLLECTION_FILTER_FILTER_FUNC_CHANGED_SIGNAL], 0);
#line 1216 "collection.c"
}


static void boxes_collection_filter_class_init (BoxesCollectionFilterClass * klass) {
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	boxes_collection_filter_parent_class = g_type_class_peek_parent (klass);
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_type_class_add_private (klass, sizeof (BoxesCollectionFilterPrivate));
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_collection_filter_get_property;
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_collection_filter_set_property;
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_collection_filter_finalize;
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_FILTER_TEXT, boxes_collection_filter_properties[BOXES_COLLECTION_FILTER_TEXT] = g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	boxes_collection_filter_signals[BOXES_COLLECTION_FILTER_FILTER_FUNC_CHANGED_SIGNAL] = g_signal_new ("filter-func-changed", BOXES_TYPE_COLLECTION_FILTER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1235 "collection.c"
}


static void boxes_collection_filter_instance_init (BoxesCollectionFilter * self) {
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->priv = BOXES_COLLECTION_FILTER_GET_PRIVATE (self);
#line 1242 "collection.c"
}


static void boxes_collection_filter_finalize (GObject * obj) {
	BoxesCollectionFilter * self;
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter);
#line 62 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->priv->terms = (_vala_array_free (self->priv->terms, self->priv->terms_length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_g_free0 (self->priv->_text);
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (boxes_collection_filter_parent_class)->finalize (obj);
#line 1256 "collection.c"
}


GType boxes_collection_filter_get_type (void) {
	static volatile gsize boxes_collection_filter_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_filter_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesCollectionFilterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_collection_filter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesCollectionFilter), 0, (GInstanceInitFunc) boxes_collection_filter_instance_init, NULL };
		GType boxes_collection_filter_type_id;
		boxes_collection_filter_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesCollectionFilter", &g_define_type_info, 0);
		g_once_init_leave (&boxes_collection_filter_type_id__volatile, boxes_collection_filter_type_id);
	}
	return boxes_collection_filter_type_id__volatile;
}


static void _vala_boxes_collection_filter_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesCollectionFilter * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter);
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	switch (property_id) {
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		case BOXES_COLLECTION_FILTER_TEXT:
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		g_value_set_string (value, boxes_collection_filter_get_text (self));
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 1283 "collection.c"
		default:
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 1289 "collection.c"
	}
}


static void _vala_boxes_collection_filter_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesCollectionFilter * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter);
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	switch (property_id) {
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		case BOXES_COLLECTION_FILTER_TEXT:
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		boxes_collection_filter_set_text (self, g_value_get_string (value));
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 1305 "collection.c"
		default:
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 58 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
		break;
#line 1311 "collection.c"
	}
}


GType boxes_category_kind_get_type (void) {
	static volatile gsize boxes_category_kind_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_category_kind_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_CATEGORY_KIND_USER, "BOXES_CATEGORY_KIND_USER", "user"}, {BOXES_CATEGORY_KIND_NEW, "BOXES_CATEGORY_KIND_NEW", "new"}, {BOXES_CATEGORY_KIND_FAVORITES, "BOXES_CATEGORY_KIND_FAVORITES", "favorites"}, {BOXES_CATEGORY_KIND_PRIVATE, "BOXES_CATEGORY_KIND_PRIVATE", "private"}, {BOXES_CATEGORY_KIND_SHARED, "BOXES_CATEGORY_KIND_SHARED", "shared"}, {0, NULL, NULL}};
		GType boxes_category_kind_type_id;
		boxes_category_kind_type_id = g_enum_register_static ("BoxesCategoryKind", values);
		g_once_init_leave (&boxes_category_kind_type_id__volatile, boxes_category_kind_type_id);
	}
	return boxes_category_kind_type_id__volatile;
}


BoxesCategory* boxes_category_construct (GType object_type, const gchar* name, BoxesCategoryKind kind) {
	BoxesCategory * self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	BoxesCategoryKind _tmp2_;
#line 113 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 113 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = (BoxesCategory*) g_object_new (object_type, NULL);
#line 114 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp0_ = name;
#line 114 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 114 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_g_free0 (self->name);
#line 114 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->name = _tmp1_;
#line 115 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_tmp2_ = kind;
#line 115 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self->kind = _tmp2_;
#line 113 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return self;
#line 1351 "collection.c"
}


BoxesCategory* boxes_category_new (const gchar* name, BoxesCategoryKind kind) {
#line 113 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	return boxes_category_construct (BOXES_TYPE_CATEGORY, name, kind);
#line 1358 "collection.c"
}


static void boxes_category_class_init (BoxesCategoryClass * klass) {
#line 101 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	boxes_category_parent_class = g_type_class_peek_parent (klass);
#line 101 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_category_finalize;
#line 1367 "collection.c"
}


static void boxes_category_instance_init (BoxesCategory * self) {
}


static void boxes_category_finalize (GObject * obj) {
	BoxesCategory * self;
#line 101 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_CATEGORY, BoxesCategory);
#line 110 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	_g_free0 (self->name);
#line 101 "/home/fborges/checkout/gnome-boxes/src/collection.vala"
	G_OBJECT_CLASS (boxes_category_parent_class)->finalize (obj);
#line 1383 "collection.c"
}


GType boxes_category_get_type (void) {
	static volatile gsize boxes_category_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_category_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesCategoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_category_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesCategory), 0, (GInstanceInitFunc) boxes_category_instance_init, NULL };
		GType boxes_category_type_id;
		boxes_category_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesCategory", &g_define_type_info, 0);
		g_once_init_leave (&boxes_category_type_id__volatile, boxes_category_type_id);
	}
	return boxes_category_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



